/*
 *******************************************************************************
 * touchscreen library header : TSlib.h
 *******************************************************************************
 *
 * source code for mikro C compiler V8.2
 * feel free to use this code at your own risks
 *
 * Author : Bruno Gavand, October 2008
 * see more details on http://www.micro-examples.com/
 *
 *******************************************************************************
 */
 
/*
 * macro definition to build TRIS and PORT register names
 * for example : TS_MKREG(TRIS, A.F0) will be turned into TRISA.F0
 */
#define TS_MKREG(a, b)    TS_REG(a, b)
#define TS_REG(a, b)    a##b

/*
 * macro definition to set TRIS for plates activation
 */
#define TS_TRIS(xp, yp, xm, ym) TS_MKREG(TRIS, TS_YM) = ym ;    \
                                TS_MKREG(TRIS, TS_XM) = xm ;    \
                                TS_MKREG(TRIS, TS_YP) = yp ;    \
                                TS_MKREG(TRIS, TS_XP) = xp ;    \

/*
 * macro definition to set PORT for plates activation
 */
#define TS_PORT(xp, yp, xm, ym) TS_MKREG(PORT, TS_YM) = ym ;    \
                                TS_MKREG(PORT, TS_XM) = xm ;    \
                                TS_MKREG(PORT, TS_YP) = yp ;    \
                                TS_MKREG(PORT, TS_XP) = xp ;    \

/*
 * macro definitions for touchscreen calibration
 */
#define TS_calibrateTL()        TS_calibrate(&tsConfig.pxmin, &tsConfig.pymin)      // top left calibration
#define TS_calibrateBR()        TS_calibrate(&tsConfig.pxmax, &tsConfig.pymax)       // bottom right

/*
 * Fieds constants
 */
#define TS_NULL         (const TS_FIELD *)0
#define TS_FIELD_END   { 0, 0, 0, 0, 0 }

/*
 * FIELD structure
 */
typedef struct
        {
        unsigned char   num ;                   // field number
        unsigned char   c1, c2, c3, c4 ;        // field box coordinates : top left, bottom right
        } TS_FIELD ;

/*
 * CONFIG structure
 */
typedef struct
        {
        int    pxmin, pymin, pxmax, pymax ;     // top left and bottom right coordinates
        } TS_CONFIG ;

extern TS_CONFIG tsConfig ;

/********************
 * public function prototypes
 */
unsigned char TS_touched() ;
signed char   TS_read(int *px, int *py, TS_FIELD *scr) ;
void    TS_calibrate(int *px, int *py) ;
